<p align="center">
  <a href="https://fastapi.tiangolo.com"><img src="https://raw.githubusercontent.com/xitowzys-ISZF/FastAPI-Auto-Generate-Gateway/main/raw/FastAPI-API-Gateway-Magic-logo.png" alt="FastAPI"></a>
</p>

<p align="center">
<a href="https://www.python.org/"> <img src="https://img.shields.io/badge/made%20with-python%20%F0%9F%90%8D-brightgreen" alt="madewithpython" border="0"></a>
</p>

<p align="center">

<a href="https://github.com/xitowzys-ISZF/FastAPI-auto-generate-gateway/blob/dev/LICENSE)" target="_blank">
    <img src="https://scrutinizer-ci.com/g/xitowzys-ISZF/FastAPI-auto-generate-gateway/badges/quality-score.png?b=dev" alt="Supported Python versions">    
    <img src="https://scrutinizer-ci.com/g/xitowzys-ISZF/FastAPI-auto-generate-gateway/badges/code-intelligence.svg?b=dev" alt="Supported Python versions">
    <img src="https://scrutinizer-ci.com/g/xitowzys-ISZF/FastAPI-auto-generate-gateway/badges/build.png?b=dev" alt="Supported Python versions">
</a>

</p>
<p align="center">

<a href="https://github.com/xitowzys-ISZF/FastAPI-auto-generate-gateway/blob/dev/LICENSE)" target="_blank">
    <img src="https://img.shields.io/github/license/xitowzys-ISZF/FastAPI-auto-generate-gateway" alt="Supported Python versions">
    <img src="https://raw.githubusercontent.com/xitowzys-ISZF/FastAPI-Auto-Generate-Gateway/main/raw/coverage.svg" alt="Supported Python versions">
    <img alt="GitHub release (latest by date)" src="https://img.shields.io/github/v/release/xitowzys-ISZF/FastAPI-auto-generate-gateway">
    <img alt="GitHub all releases" src="https://img.shields.io/github/downloads/xitowzys-ISZF/FastAPI-auto-generate-gateway/total">

</a>

</p>

<p align="center">
    <a href="https://xitowzys-iszf.github.io/FastAPI-auto-generate-gateway/" target="_blank">
        <img src="https://img.shields.io/badge/Documentation-ef5552?style=for-the-badge&logo=Read the Docs&logoColor=ffffff" alt="Supported Python versions">
    </a>
    <a href="https://github.com/xitowzys-ISZF/FastAPI-auto-generate-gateway/tree/dev/fastapi_gateway_auto_generate" target="_blank">
        <img src="https://img.shields.io/badge/Source_code-0953dc?style=for-the-badge&logo=Github&logoColor=fffff" alt="Supported Python versions">
    </a>
</p>

# 🔥 FastAPI Auto Generate Gateway

A library that allows you to automate the process of creating an API Gateway

# 📚 About

This is a library that enables the automation of the process of creating an API Gateway. 
With its help, you can quickly and easily configure and deploy an API Gateway for your microservices architecture.
The library provides a simple and intuitive interface for configuration, 
which reduces the time and effort required to manually set up the API Gateway.









